@@ -13,21 +13,21 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "advancedsearchdialog.h"
+
 #include <kcombobox.h>
 #include <klineedit.h>
 #include <kpushbutton.h>
 #include <klocale.h>
+#include <kvbox.h>
 
-#include <qradiobutton.h>
-#include <qvgroupbox.h>
-#include <qlabel.h>
-#include <qhbox.h>
-#include <qvbox.h>
-#include <qlayout.h>
-#include <qhbuttongroup.h>
+#include <QRadioButton>
+#include <QLabel>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+#include <QGroupBox>
 
 #include "collectionlist.h"
-#include "advancedsearchdialog.h"
 #include "searchwidget.h"
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -35,31 +35,51 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 AdvancedSearchDialog::AdvancedSearchDialog(const QString &defaultName,
-					   const PlaylistSearch &defaultSearch,
+                                           const PlaylistSearch &defaultSearch,
                                            QWidget *parent,
                                            const char *name) :
-    KDialogBase(parent, name, true, i18n("Create Search Playlist"), Ok|Cancel)
+    KDialog(parent)
 {
-    makeVBoxMainWidget();
+    setCaption( i18n("Create Search Playlist") );
+    setButtons( Ok|Cancel );
+    setDefaultButton( Ok );
+    setObjectName(name);
+    setModal(true);
 
-    QHBox *box = new QHBox(mainWidget());
+    KVBox *mw = new KVBox(this);
+    setMainWidget(mw);
+
+    KHBox *box = new KHBox(mw);
     box->setSpacing(5);
 
     new QLabel(i18n("Playlist name:"), box);
     m_playlistNameLineEdit = new KLineEdit(defaultName, box);
 
-    QVGroupBox *criteriaGroupBox = new QVGroupBox(i18n("Search Criteria"), mainWidget());
-    static_cast<QHBox *>(mainWidget())->setStretchFactor(criteriaGroupBox, 1);
+    QGroupBox *criteriaGroupBox = new QGroupBox(i18n("Search Criteria"), mw);
+    mw->setStretchFactor(criteriaGroupBox, 1);
 
-    QHButtonGroup *group = new QHButtonGroup(criteriaGroupBox);
-    m_matchAnyButton = new QRadioButton(i18n("Match any of the following"), group);
-    m_matchAllButton = new QRadioButton(i18n("Match all of the following"), group);
+    m_criteriaLayout = new QVBoxLayout;
 
-    m_criteria = new QVBox(criteriaGroupBox);
+    QGroupBox *group = new QGroupBox();
+
+    m_matchAnyButton = new QRadioButton(i18n("Match any of the following"));
+    m_matchAllButton = new QRadioButton(i18n("Match all of the following"));
+
+    QHBoxLayout *hgroupbox = new QHBoxLayout;
+    hgroupbox->addWidget(m_matchAnyButton);
+    hgroupbox->addWidget(m_matchAllButton);
+
+    group->setLayout(hgroupbox);
+
+    m_criteriaLayout->addWidget(group);
 
     if(defaultSearch.isNull()) {
-        m_searchLines.append(new SearchLine(m_criteria));
-        m_searchLines.append(new SearchLine(m_criteria));
+        SearchLine *newSearchLine = new SearchLine(this);
+        m_searchLines.append(newSearchLine);
+        m_criteriaLayout->addWidget(newSearchLine);
+        newSearchLine = new SearchLine(this);
+        m_searchLines.append(newSearchLine);
+        m_criteriaLayout->addWidget(newSearchLine);
         m_matchAnyButton->setChecked(true);
     }
     else {
@@ -68,9 +88,10 @@ AdvancedSearchDialog::AdvancedSearchDialog(const QString &defaultName,
             it != components.end();
             ++it)
         {
-            SearchLine *s = new SearchLine(m_criteria);
+            SearchLine *s = new SearchLine(this);
             s->setSearchComponent(*it);
             m_searchLines.append(s);
+            m_criteriaLayout->addWidget(s);
         }
         if(defaultSearch.searchMode() == PlaylistSearch::MatchAny)
             m_matchAnyButton->setChecked(true);
@@ -78,16 +99,18 @@ AdvancedSearchDialog::AdvancedSearchDialog(const QString &defaultName,
             m_matchAllButton->setChecked(true);
     }
 
-    QWidget *buttons = new QWidget(criteriaGroupBox);
-    QBoxLayout *l = new QHBoxLayout(buttons, 0, 5);
+    QWidget *buttons = new QWidget(mw);
+    QHBoxLayout *l = new QHBoxLayout(buttons);
+    l->setSpacing(5);
+    l->setMargin(0);
 
-    KPushButton *clearButton = new KPushButton(KStdGuiItem::clear(), buttons);
+    KPushButton *clearButton = new KPushButton(KStandardGuiItem::clear(), buttons);
     connect(clearButton, SIGNAL(clicked()), SLOT(clear()));
     l->addWidget(clearButton);
 
     l->addStretch(1);
 
-    m_moreButton = new KPushButton(i18n("More"), buttons);
+    m_moreButton = new KPushButton(i18nc("additional search options", "More"), buttons);
     connect(m_moreButton, SIGNAL(clicked()), SLOT(more()));
     l->addWidget(m_moreButton);
 
@@ -95,6 +118,10 @@ AdvancedSearchDialog::AdvancedSearchDialog(const QString &defaultName,
     connect(m_fewerButton, SIGNAL(clicked()), SLOT(fewer()));
     l->addWidget(m_fewerButton);
 
+    m_criteriaLayout->addStretch(1);
+
+    criteriaGroupBox->setLayout(m_criteriaLayout);
+
     m_playlistNameLineEdit->setFocus();
 }
 
@@ -110,7 +137,7 @@ AdvancedSearchDialog::~AdvancedSearchDialog()
 AdvancedSearchDialog::Result AdvancedSearchDialog::exec()
 {
     Result r;
-    r.result = DialogCode(KDialogBase::exec());
+    r.result = DialogCode(KDialog::exec());
     r.search = m_search;
     r.playlistName = m_playlistName;
     return r;
@@ -127,7 +154,7 @@ void AdvancedSearchDialog::accept()
 
     m_search.addPlaylist(CollectionList::instance());
 
-    QValueListConstIterator<SearchLine *> it = m_searchLines.begin();
+    QList<SearchLine *>::const_iterator it = m_searchLines.begin();
     for(; it != m_searchLines.end(); ++it)
         m_search.addComponent((*it)->searchComponent());
 
@@ -136,19 +163,20 @@ void AdvancedSearchDialog::accept()
 
     m_playlistName = m_playlistNameLineEdit->text();
 
-    KDialogBase::accept();
+    KDialog::accept();
 }
 
 void AdvancedSearchDialog::clear()
 {
-    QValueListConstIterator<SearchLine *> it = m_searchLines.begin();
+    QList<SearchLine *>::const_iterator it = m_searchLines.begin();
     for(; it != m_searchLines.end(); ++it)
         (*it)->clear();
 }
 
 void AdvancedSearchDialog::more()
 {
-    SearchLine *searchLine = new SearchLine(m_criteria);
+    SearchLine *searchLine = new SearchLine(this);
+    m_criteriaLayout->addWidget(searchLine);
     m_searchLines.append(searchLine);
     searchLine->show();
     updateButtons();
@@ -157,7 +185,7 @@ void AdvancedSearchDialog::more()
 void AdvancedSearchDialog::fewer()
 {
     SearchLine *searchLine = m_searchLines.last();
-    m_searchLines.remove(searchLine);
+    m_searchLines.removeAll(searchLine);
     delete searchLine;
     updateButtons();
 }
@@ -173,3 +201,5 @@ void AdvancedSearchDialog::updateButtons()
 }
 
 #include "advancedsearchdialog.moc"
+
+// vim: set et sw=4 tw=0 sta:
