@@ -13,17 +13,17 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qstring.h>
-
-#include "filerenameroptions.h"
 #include "categoryreaderinterface.h"
+#include "filerenameroptions.h"
+
+#include <QString>
 
 QString CategoryReaderInterface::value(const CategoryID &category) const
 {
-    QString value = categoryValue(category.category).stripWhiteSpace();
+    QString value = categoryValue(category.category).trimmed();
 
     if(category.category == Track)
-        value = fixupTrack(value, category.categoryNumber).stripWhiteSpace();
+        value = fixupTrack(value, category.categoryNumber).trimmed();
 
     if(value.isEmpty() && emptyAction(category) == TagRenamerOptions::UseReplacementValue)
         value = emptyText(category);
@@ -41,7 +41,7 @@ bool CategoryReaderInterface::isEmpty(TagType category) const
     return categoryValue(category).isEmpty();
 }
 
-QString CategoryReaderInterface::fixupTrack(const QString &track, unsigned categoryNum) const
+QString CategoryReaderInterface::fixupTrack(const QString &track, int categoryNum) const
 {
     QString str(track);
     CategoryID trackId(Track, categoryNum);
@@ -50,10 +50,10 @@ QString CategoryReaderInterface::fixupTrack(const QString &track, unsigned categ
         if(emptyAction(trackId) == TagRenamerOptions::UseReplacementValue)
             str = emptyText(trackId);
         else
-            return QString::null;
+            return QString();
     }
 
-    unsigned minimumWidth = trackWidth(categoryNum);
+    int minimumWidth = trackWidth(categoryNum);
 
     if(str.length() < minimumWidth) {
         QString prefix;
@@ -64,4 +64,4 @@ QString CategoryReaderInterface::fixupTrack(const QString &track, unsigned categ
     return str;
 }
 
-// vim: set et sw=4 ts=4:
+// vim: set et sw=4 tw=0 sta:
