@@ -16,19 +16,17 @@
 #ifndef COLLECTIONLIST_H
 #define COLLECTIONLIST_H
 
-#include <kapplication.h>
-#include <kdirwatch.h>
-
-#include <qdict.h>
-#include <qclipboard.h>
-#include <qvaluevector.h>
+#include <QHash>
+#include <QVector>
 
 #include "playlist.h"
 #include "playlistitem.h"
-#include "sortedstringlist.h"
 
 class CollectionListItem;
 class ViewMode;
+class KFileItem;
+class KFileItemList;
+class KDirWatch;
 
 /**
  * This type is for mapping QString track attributes like the album, artist
@@ -36,24 +34,24 @@ class ViewMode;
  * that hold the string.
  */
 
-typedef QDict<int> TagCountDict;
-typedef QDictIterator<int> TagCountDictIterator;
+typedef QHash<QString, int> TagCountDict;
+typedef QHashIterator<QString, int> TagCountDictIterator;
 
 /**
- * We then have an array of dicts, one for each column in the list view.  We
- * use pointers to TagCountDicts because QDict has a broken copy ctor, which
- * doesn't copy the case sensitivity setting.
+ * We then have an array of dicts, one for each column in the list view.
+ * The array is sparse (not every vector will have a TagCountDict so we use
+ * pointers.
  */
 
-typedef QValueVector<TagCountDict*> TagCountDicts;
+typedef QVector<TagCountDict *> TagCountDicts;
 
-/** 
+/**
  * This is the "collection", or all of the music files that have been opened
  * in any playlist and not explicitly removed from the collection.
  *
  * It is being implemented as a "semi-singleton" because I need universal access
- * to just one instance.  However, because the collection needs initialization 
- * parameters (that will not always be available when an instance is needed).  
+ * to just one instance.  However, because the collection needs initialization
+ * parameters (that will not always be available when an instance is needed).
  * Hence there will be the familiar singleton "instance()" method allong with an
  * "initialize()" method.
  */
@@ -64,7 +62,7 @@ class CollectionList : public Playlist
 
     Q_OBJECT
 
-public: 
+public:
     /**
      * A variety of unique value lists will be kept in the collection.  This
      * enum can be used as an index into those structures.
@@ -79,11 +77,11 @@ public:
      */
     QStringList uniqueSet(UniqueSetType t) const;
 
-    CollectionListItem *lookup(const QString &file) { return m_itemsDict.find(file); }
-    
+    CollectionListItem *lookup(const QString &file) const;
+
     virtual PlaylistItem *createItem(const FileHandle &file,
-				     QListViewItem * = 0,
-				     bool = false);
+                                     Q3ListViewItem * = 0,
+                                     bool = false);
 
     void emitVisibleColumnsChanged() { emit signalVisibleColumnsChanged(); }
 
@@ -91,14 +89,20 @@ public:
 
     void setupTreeViewEntries(ViewMode *viewMode) const;
 
+    virtual bool canReload() const { return true; }
+
 public slots:
-    virtual void paste() { decode(kapp->clipboard()->data()); }
+    virtual void paste();
     virtual void clear();
     void slotCheckCache();
 
     void slotRemoveItem(const QString &file);
     void slotRefreshItem(const QString &file);
-    
+
+    void slotNewItems(const KFileItemList &items);
+    void slotRefreshItems(const QList<QPair<KFileItem, KFileItem> > &items);
+    void slotDeleteItem(const KFileItem &item);
+
 protected:
     CollectionList(PlaylistCollection *collection);
     virtual ~CollectionList();
@@ -108,17 +112,19 @@ protected:
 
     // These methods are used by CollectionListItem, which is a friend class.
 
-    void addToDict(const QString &file, CollectionListItem *item) { m_itemsDict.replace(file, item); }
+    void addToDict(const QString &file, CollectionListItem *item) { m_itemsDict.insert(file, item); }
     void removeFromDict(const QString &file) { m_itemsDict.remove(file); }
 
     // These methods are also used by CollectionListItem, to manage the
     // strings used in generating the unique sets and tree view mode playlists.
 
-    QString addStringToDict(const QString &value, unsigned column);
-    void removeStringFromDict(const QString &value, unsigned column);
+    QString addStringToDict(const QString &value, int column);
+    void removeStringFromDict(const QString &value, int column);
 
-    void addWatched(const QString &file) { m_dirWatch->addFile(file); }
-    void removeWatched(const QString &file) { m_dirWatch->removeFile(file); }
+    void addWatched(const QString &file);
+    void removeWatched(const QString &file);
+
+    virtual bool hasItem(const QString &file) const { return m_itemsDict.contains(file); }
 
 signals:
     void signalCollectionChanged();
@@ -131,9 +137,7 @@ signals:
      * \see Playlsit::isColumnVisible()
      */
     void signalVisibleColumnsChanged();
-
     void signalNewTag(const QString &, unsigned);
-
     void signalRemovedTag(const QString &, unsigned);
 
 private:
@@ -144,7 +148,7 @@ private:
     static const int m_uniqueSetCount = 3;
 
     static CollectionList *m_list;
-    QDict<CollectionListItem> m_itemsDict;
+    QHash<QString, CollectionListItem *> m_itemsDict;
     KDirWatch *m_dirWatch;
     TagCountDicts m_columnTags;
 };
@@ -155,15 +159,12 @@ class CollectionListItem : public PlaylistItem
     friend class CollectionList;
     friend class PlaylistItem;
 
-    /** 
-     * Needs access to the destructor, even though the destructor isn't used by QDict.
-     */
-    friend class QDict<CollectionListItem>;
-
 public:
     virtual void refresh();
-    PlaylistItem *itemForPlaylist(const Playlist *playlist) const;
+    PlaylistItem *itemForPlaylist(const Playlist *playlist);
     void updateCollectionDict(const QString &oldPath, const QString &newPath);
+    void repaint() const;
+    PlaylistItemList children() const { return m_children; }
 
 protected:
     CollectionListItem(const FileHandle &file);
@@ -186,3 +187,5 @@ private:
 };
 
 #endif
+
+// vim: set et sw=4 tw=0 sta:
