@@ -16,16 +16,13 @@
 #ifndef JUK_H
 #define JUK_H
 
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 
 #include "playermanager.h"
+#include <QKeyEvent>
 
-class QTimer;
-class QListViewItem;
 
 class KToggleAction;
-class KSelectAction;
-class KToolBarPopupAction;
 class KGlobalAccel;
 
 class SliderAction;
@@ -34,15 +31,17 @@ class SystemTray;
 class PlayerManager;
 class PlaylistSplitter;
 
-class JuK : public KMainWindow
+class JuK : public KXmlGuiWindow
 {
     Q_OBJECT
 
 public:
-    JuK(QWidget* parent = 0, const char *name = 0);
+    JuK(QWidget* parent = 0);
     virtual ~JuK();
     virtual KActionCollection *actionCollection() const;
 
+    static JuK* JuKInstance();
+
 private:
     void setupLayout();
     void setupActions();
@@ -87,7 +86,6 @@ private:
     KToggleAction *m_togglePopupsAction;
     KToggleAction *m_toggleSplashAction;
     KToggleAction *m_loopPlaylistAction;
-    KSelectAction *m_outputSelectAction;
 
     PlayerManager *m_player;
     KGlobalAccel *m_accel;
@@ -95,6 +93,10 @@ private:
     bool m_startDocked;
     bool m_showSplash;
     bool m_shuttingDown;
+
+    static JuK* m_instance;
 };
 
 #endif
+
+// vim: set et sw=4 tw=0 sta:
