@@ -27,8 +27,11 @@
 #include <kdemacros.h>
 extern "C"
 {
+	//cdda_interface.h in cdparanoia 10.2 has a member called 'private' which the C++ compiler doesn't like
+	#define private _private   
 	#include <cdda_interface.h>
 	#include <cdda_paranoia.h>
+	#undef private
 	void paranoiaCallback(long, int);
 
 	KDE_EXPORT int kdemain(int argc, char ** argv);
@@ -212,7 +215,8 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 
 	// Update our knowledge of the disc
 #if defined(HAVE_CDDA_IOCTL_DEVICE)
- 	d->cd.setDevice(drive->ioctl_device_name, 50, false);
+	if (d->cd.deviceName() != drive->ioctl_device_name)
+		d->cd.setDevice(drive->ioctl_device_name, 50, false);
 #else
 	// FreeBSD's cdparanoia as of january 5th 2006 has rather broken
 	// support for non-SCSI devices. Although it finds ATA cdroms just
