@@ -17,42 +17,42 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef KMIXDOCKWIDGET_H
 #define KMIXDOCKWIDGET_H
 
-class QFrame;
 class QString;
-#include <qwidget.h>
-#include <qvbox.h>
+#include <QWidget>
 
-#include <ksystemtray.h>
+#include <ksystemtrayicon.h>
 
+class KMixWindow;
 class Mixer;
-class KAudioPlayer;
-class MixDeviceWidget;
-class Mixer;
-class ViewDockAreaPopup;
+//class ViewDockAreaPopup;
 class Volume;
 
-class KMixDockWidget : public KSystemTray  {
+namespace Phonon
+{
+       class MediaObject;
+}
+
+class KMixDockWidget : public KSystemTrayIcon  {
    Q_OBJECT
 
    friend class KMixWindow;
 
  public:
-   KMixDockWidget(Mixer *, QWidget *parent=0, const char *name=0, bool volumePopup=true);
+   explicit KMixDockWidget(KMixWindow *parent, QWidget *referenceWidget, bool volumePopup);
    ~KMixDockWidget();
 
    void setErrorPixmap();
    void ignoreNextEvent();
-   ViewDockAreaPopup* getDockAreaPopup();
+   //ViewDockAreaPopup* getDockAreaPopup();
 
    Mixer *m_mixer;
-   ViewDockAreaPopup *_dockAreaPopup;
-   KAudioPlayer *_audioPlayer;
+   Phonon::MediaObject *_audioPlayer;
 
  public slots:
    void setVolumeTip();
@@ -61,11 +61,11 @@ class KMixDockWidget : public KSystemTray  {
  protected:
    void createMasterVolWidget();
    void createActions();
-   void mousePressEvent(QMouseEvent *);
-   void mouseReleaseEvent(QMouseEvent *);
-   void wheelEvent(QWheelEvent *);
-   void contextMenuAboutToShow( KPopupMenu* menu );
+   void moveVolumePopoup();
+   void trayWheelEvent(QWheelEvent *);
+//    void trayToolTipEvent(QHelpEvent *e );
    void toggleMinimizeRestore();
+   bool event( QEvent *);
 
  private:
    bool _playBeepOnVolumeChange;
@@ -73,10 +73,13 @@ class KMixDockWidget : public KSystemTray  {
    int  _oldToolTipValue;
    char _oldPixmapType;
    bool _volumePopup;
+   KMixWindow* _kmixMainWindow;
  private slots:
    void dockMute();
+   void kmixSystrayAction(QSystemTrayIcon::ActivationReason);
    void selectMaster();
-   void handleNewMaster(int soundcard_id, QString& channel_id);
+   void handleNewMaster(QString& soundcard_id, QString& channel_id);
+   void contextMenuAboutToShow();
 };
 
 #endif
