@@ -15,14 +15,15 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
+#include "synccddbplookup.h"
+
 #include <qstringlist.h>
 #include <kdebug.h>
-
-#include "synccddbplookup.h"
+#include <ksocketfactory.h>
 
 namespace KCDDB
 {
@@ -36,7 +37,7 @@ namespace KCDDB
     // Empty.
   }
 
-    CDDB::Result
+    Result
   SyncCDDBPLookup::lookup
   (
     const QString         & hostName,
@@ -44,22 +45,25 @@ namespace KCDDB
     const TrackOffsetList & trackOffsetList
   )
   {
-    if ( trackOffsetList.count() < 3 )
-      return UnknownError;
-
     trackOffsetList_ = trackOffsetList;
 
-    socket_ = new KNetwork::KBufferedSocket(hostName, QString::number(port));
-    socket_->setTimeout( 30000 );
-    socket_->setOutputBuffering(false);
+    socket_ = KSocketFactory::synchronousConnectToHost("cddbp", hostName, port);
+
+    if ( !socket_->isValid() )
+    {
+      kDebug(60010) << "Couldn't connect to " << socket_->peerName() << ":" << socket_->peerPort();
+      kDebug(60010) << "Socket error: " << socket_->errorString();
+
+      if ( socket_->error() == QAbstractSocket::HostNotFoundError )
+        return HostNotFound;
+      else if ( socket_->error() == QAbstractSocket::SocketTimeoutError )
+        return NoResponse;
+      else
+        return UnknownError;
+    }
 
     Result result;
 
-    // Connect to server.
-    result = connect();
-    if ( Success != result )
-      return result;
-
     // Try a handshake.
     result = shakeHands();
     if ( Success != result )
@@ -73,7 +77,7 @@ namespace KCDDB
     if (matchList_.isEmpty())
       return NoRecordFound;
 
-    kdDebug(60010) << matchList_.count() << " matches found." << endl;
+    kDebug(60010) << matchList_.count() << " matches found.";
 
     // For each match, read the cd info from the server and save it to
     // cdInfoList.
@@ -93,28 +97,7 @@ namespace KCDDB
     return Success;
   }
 
-    CDDB::Result
-  SyncCDDBPLookup::connect()
-  {
-    kdDebug(60010) << "Trying to connect to " << endl;
-
-    if ( !socket_->lookup() )
-      return HostNotFound;
-
-    socket_->peerResolver().wait();
-
-    if ( socket_->state() != KNetwork::KClientSocketBase::HostFound )
-      return HostNotFound;
-
-    if ( !socket_->connect() )
-      return ServerError;
-
-    socket_->waitForConnect();
-
-    return isConnected() ? Success : ServerError;
-  }
-
-    CDDB::Result
+    Result
   SyncCDDBPLookup::shakeHands()
   {
     QString line = readLine();
@@ -137,7 +120,7 @@ namespace KCDDB
     return Success;
   }
 
-    CDDB::Result
+    Result
   SyncCDDBPLookup::runQuery()
   {
     Result result;
@@ -161,11 +144,11 @@ namespace KCDDB
         line = readLine();
       }
     }
- 
+
     return Success;
   }
 
-    CDDB::Result
+    Result
   SyncCDDBPLookup::matchToCDInfo( const CDDBMatch & match )
   {
     sendRead( match );
@@ -189,7 +172,9 @@ namespace KCDDB
 
     if ( info.load( lineList ) )
     {
-      info.category = category_;
+      info.set( "category", category_ );
+      info.set( "discid", discid_ );
+      info.set( "source", "freedb" );
       cdInfoList_.append( info );
     }
 
@@ -201,18 +186,14 @@ namespace KCDDB
   {
     if ( !isConnected() )
     {
-      kdDebug(60010) << "socket status: " << socket_->state() << endl;
-      return QString::null;
+      kDebug(60010) << "socket status: " << socket_->state();
+      return QString();
     }
 
     if (!socket_->canReadLine())
     {
-      bool timeout;
-
-      socket_->waitForMore(-1,&timeout);
-
-      if (timeout)
-        return QString::null;
+      if (!socket_->waitForReadyRead(-1))
+        return QString();
     }
 
     return QString::fromUtf8(socket_->readLine());
